WishBone
========

What?
-----

A Python framework to build composable event pipeline servers with minimal effort.

Documentation
-------------

https://wishbone.readthedocs.org/en/latest/index.html


Support
-------

Drop me an email or post a message on:

https://groups.google.com/forum/?fromgroups#!forum/python-wishbone
